--- boost/typeof/typeof.hpp.orig	2015-04-22 10:56:33.000000000 -0400
+++ boost/typeof/typeof.hpp	2015-04-15 14:33:17.000000000 -0400
@@ -31,7 +31,8 @@
 #       endif
 #   endif
 
-#elif defined(__INTEL_COMPILER) || defined(__ICL) || defined(__ICC) || defined(__ECC)
+#elif (defined(__INTEL_COMPILER) || defined(__ICL) || defined(__ICC) || defined(__ECC) ) && \
+               __INTEL_COMPILER < 1500
 #   ifdef __GNUC__
 #       ifndef BOOST_TYPEOF_EMULATION
 #           ifndef BOOST_TYPEOF_NATIVE
--- boost/config/compiler/intel.hpp.orig	2015-04-22 11:00:41.000000000 -0400
+++ boost/config/compiler/intel.hpp	2015-04-17 09:40:42.000000000 -0400
@@ -16,6 +16,26 @@
 
 #include "boost/config/compiler/common_edg.hpp"
 
+#if defined(__INTEL_COMPILER) &&  __INTEL_COMPILER >= 1500
+/* Intel(R) C++ Compiler (CQ358241) */
+/* 1) Add any Intel-specific generic pre-adjustments HERE */
+#ifdef __GNUC__
+/* 2) Add any Intel-specific gcc pre-adjustments HERE */
+#include "boost/config/compiler/gcc.hpp"
+/* 3) Add any Intel-specific gcc post-adjustments HERE */
+#elif _MSC_VER
+/* 4) Add any Intel-specific MS pre-adjustments HERE */
+#include "boost/config/compiler/visualc.hpp"
+/* 5) Add any Intel-specific MS post-adjustments HERE */
+#elif defined( __clang__ )
+#include "boost/config/compiler/clang.hpp"
+#else
+/* 6) Settings for ISPC or other Intel compilers here */
+#error "Invalid mode detected: expected __GNUC__ || _MSC_VER"
+#endif /* GNUC || MSVC */
+/* 7) Add any Intel-specific generic post-adjustments HERE */
+#else /* !__INTEL_COMPILER &&  >= 1500 */
+
 #if defined(__INTEL_COMPILER)
 #if __INTEL_COMPILER == 9999
 #  define BOOST_INTEL_CXX_VERSION 1200 // Intel bug in 12.1.
@@ -454,5 +474,6 @@
 //
 //#     pragma message("Unknown compiler version - please run the configure tests and report the results")
 #  endif
+#endif /* __INTEL_COMPILER >= 1500 */
 #endif
 
--- boost/config/compiler/common_edg.hpp.orig	2015-04-22 11:00:55.000000000 -0400
+++ boost/config/compiler/common_edg.hpp	2015-04-17 09:41:40.000000000 -0400
@@ -75,6 +75,22 @@
 #  define BOOST_NO_CXX11_VARIADIC_MACROS
 #endif
 
+#if defined(__INTEL_COMPILER) &&  __INTEL_COMPILER >= 1500
+/* Intel(R) C++ Compiler (CQ361660) */
+/* 1) Add any Intel-specific generic adjustments HERE */
+#pragma warning disable 2536  /* Intel bug DPD200369164 */
+#ifdef __GNUC__
+/* 2) Add any Intel-specific gcc adjustments HERE */
+#elif _MSC_VER
+/* 3) Add any Intel-specific MS adjustments HERE */
+#elif defined( __clang__ )
+/* 3) Add any Intel-specific __clang__ adjustments HERE */
+#else
+/* 4) Settings for ISPC or other Intel compilers here */
+#error "Invalid mode detected: expected __GNUC__ || _MSC_VER"
+#endif /* GNUC || MSVC */
+#else /* !__INTEL_COMPILER &&  >= 1500 */
+
 #define BOOST_NO_CXX11_AUTO_DECLARATIONS
 #define BOOST_NO_CXX11_AUTO_MULTIDECLARATIONS
 #define BOOST_NO_CXX11_CHAR16_T
@@ -136,6 +151,8 @@
 #  define BOOST_NO_CXX14_VARIABLE_TEMPLATES
 #endif
 
+#endif /* __INTEL_COMPILER >= 1500 */
+
 #ifdef c_plusplus
 // EDG has "long long" in non-strict mode
 // However, some libraries have insufficient "long long" support
